import { Space, Button, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/BTable";
import { useEffect, useState } from "react";
import UserConfig from "@/service/apiConfig/user_config";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import Modal from "antd/lib/modal/Modal";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { useNavigate } from "react-router";
const AppManageList = (props: Store) => {
  const { appStore } = props;
  const navigate = useNavigate();
  const [id, setId] = useState<any>(null);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const [record, setRecord] = useState<any>(null);
  const formRef = React.useRef<FormInstance>(null);
  const [isModalOpen, setIsModalOpen] = useState(false);
  const columns: ColumnsType<UserDataType> = [
    { title: "app名称", dataIndex: "appName" },
    { title: "图标", dataIndex: "appIcon" },
    { title: "预览图片", dataIndex: "activeIcon" },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: {
        showTitle: false,
      },
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  edit(record);
                }}
              >
                编辑
              </Button>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  navigate("/app/config/" + record.id);
                }}
              >
                信息配置
              </Button>
              <Button
                type="dashed"
                danger
                size="small"
                onClick={() => {
                  appStore.deleteItem(record.id);
                }}
              >
                删除
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const defaultConfig = [
    {
      type: "input",
      label: "app名称",
      name: "appName",
      value: "",
      rules: [{ required: true, message: "请输入卡片名称!" }],
    },
    {
      type: "upload",
      label: "icon",
      name: "appIcon",
      value: [],
    },
    {
      type: "upload",
      label: "图片",
      name: "photosIds",
      value: [],
    },
  ];
  useEffect(() => {
    appStore.getlist(UserConfig.LIST);
  }, [appStore]);
  const onFinish = (values: any) => {
    let ids = values.photosIds.map((item) => {
      return item.id;
    });
    let appIcon = values.appIcon.map((item) => {
      return item.id;
    });
    console.log(values);
    values = {
      ...values,
      photosIds: ids.join(","),
      appIcon: appIcon.join(","),
    };
    if (!id) {
      appStore.add(values);
    } else {
      appStore.putItem(id, values);
    }
    setIsModalOpen(false);
  };
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Button
        className="projectContentAdd"
        style={{ marginBottom: "10px" }}
        onClick={() => {
          setProjectConfig(defaultConfig);
          setIsModalOpen(true);
        }}
      >
        添加app
      </Button>
      <Modal
        title="app信息"
        width={800}
        open={isModalOpen}
        onCancel={() => setIsModalOpen(false)}
        afterClose={() => formRef.current?.resetFields()}
        onOk={() => formRef.current?.submit()}
      >
        <SimpleForm
          formRef={formRef}
          createCallback={() => {
            formRef.current?.setFieldsValue(record);
          }}
          formName="card_basic"
          colProps={4}
          subBtnName="提交"
          formDatas={projectConfig}
          onFinish={onFinish}
          initialValues={true}
          onFinishFailed={onFinishFailed}
        />
      </Modal>
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <BTable store={appStore} columns={columns} dataSource={appStore.list} />
      </Space>
    </div>
  );
};

export default inject("appStore")(observer(AppManageList));
