import { Button, Space, Modal, FormInstance } from "antd";
import "./index.less";
import type { ColumnsType } from "antd/es/table";
import { CardDataType } from "@/util/model/interface";
import { inject, observer } from "mobx-react";
import BTable from "@/components/BTable";
import SimpleForm from "@/components/form/simple_form";
import { useEffect, useState } from "react";
import React from "react";
import { useNavigate } from "react-router-dom";
import CardConfig from "@/service/apiConfig/card_config";
const CurrentEventPageList = (props) => {
  const currentEventStore = props.currentEventStore;
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const [id, setId] = useState<any>(null);
  const [record, setRecord] = useState<any>(null);
  const formRef = React.useRef<FormInstance>(null);
  const [isModalOpen, setIsModalOpen] = useState(false);
  const navigate = useNavigate();
  const columns: ColumnsType<CardDataType> = [
    { title: "时事卡片编号", dataIndex: "id" },
    { title: "名称", dataIndex: "title" },
    { title: "标签", dataIndex: "tag" },
    {
      title: "封面",
      dataIndex: "imageUrl",
      render: (any, record) => (
        <div>
          <img
            src={record.imageUrl}
            alt="avatar"
            style={{ width: "80px", height: "80px" }}
          />
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: {
        showTitle: false,
      },
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  edit(record);
                }}
              >
                编辑
              </Button>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  navigate("/card/componsition/" + record.id);
                }}
              >
                用户作文
              </Button>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  currentEventStore.item = record;
                  navigate("/card/editors/" + record.id + "/1");
                }}
              >
                内容编辑
              </Button>
              <Button
                type="dashed"
                danger
                size="small"
                onClick={() => {
                  currentEventStore.deleteItem(record.id);
                }}
              >
                删除
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);

    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const defaultConfig = [
    {
      type: "input",
      label: "时事标题",
      name: "title",
      value: "",
      rules: [{ required: true, message: "请输入时事标题!" }],
    },
    {
      type: "input",
      label: "请输入标签",
      name: "tag",
      value: "",
      rules: [{ required: true, message: "请输入卡片标签" }],
    },
    {
      type: "upload",
      label: "请上传封面图",
      name: "imageUrl",
      value: [],
    },
  ];

  const onFinish = (values: any) => {
    let images = values.imageUrl.map((item) => {
      return item.response.data.url;
    });
    values = {
      ...values,
      imageUrl: images.join(","),
    };
    if (!id) {
      currentEventStore.add(values);
    } else {
      currentEventStore.putItem(id, values);
    }
    setIsModalOpen(false);
  };

  useEffect(() => {
    currentEventStore.getlist(CardConfig.CardConfig.LIST);
  }, [currentEventStore]);
  const onFinishFailed = () => {};
  return (
    <div className="projectContent">
      <Button
        className="projectContentAdd"
        onClick={() => {
          setProjectConfig(defaultConfig);
          setId(null);
          setIsModalOpen(true);
        }}
      >
        添加人物
      </Button>

      <div className="editContentBox">
        <BTable
          columns={columns}
          store={currentEventStore}
          dataSource={currentEventStore.list}
        />
      </div>
      <Modal
        title="人物信息"
        width={800}
        open={isModalOpen}
        onCancel={() => setIsModalOpen(false)}
        afterClose={() => formRef.current?.resetFields()}
        onOk={() => formRef.current?.submit()}
      >
        <SimpleForm
          formRef={formRef}
          createCallback={() => {
            formRef.current?.setFieldsValue(record);
          }}
          formName="card_basic"
          colProps={4}
          subBtnName="提交"
          formDatas={projectConfig}
          onFinish={onFinish}
          initialValues={true}
          onFinishFailed={onFinishFailed}
        />
      </Modal>
    </div>
  );
};

export default inject("currentEventStore")(observer(CurrentEventPageList));
