import BTable from "@/components/BTable";
import { Button, FormInstance, Modal, Space } from "antd";
import { ColumnsType } from "antd/lib/table";
import { inject, observer } from "mobx-react";
import { Store } from "antd/lib/form/interface";
import { useEffect, useState } from "react";
import merchantsConfig from "@/service/apiConfig/merchants_config";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import EditorComponent from "@/components/edittor";

const Merchant = (props: Store) => {
  const { merchantStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [productDesc, setProductDesc] = useState<any>(null);
  const [record, setRecord] = useState<any>(null);
  const [merchantId, setId] = useState<Number | null>(null);
  const columns: ColumnsType = [
    { title: "商家名称", dataIndex: "merchantsName" },
    { title: "商家地址", dataIndex: "address" },
    { title: "审核状态", dataIndex: "examineStatus" },
    { title: "运营范围", dataIndex: "radius" },
    { title: "风险等级", dataIndex: "riskLevel" },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: { showTitle: false },
      render: (any, record: any) => (
        <div>
          <Space align="center">
            <Button
              type="dashed"
              size="small"
              onClick={() => {
                edit(record);
              }}
            >
              编辑
            </Button>
            <Button
              type="dashed"
              danger
              size="small"
              onClick={() => {
                merchantStore.deleteItem(record.id);
              }}
            >
              删除
            </Button>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    const myrecord = {
      ...record,
      licenseImgId: record.licenseImgList,
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    setRecord(myrecord);
    formRef.current?.setFieldsValue(myrecord);
    setId(myrecord.id);
    setProductDesc(myrecord.desc);
  };
  const defaultConfig = [
    {
      type: "input",
      label: "商家名称",
      name: "merchantsName",
      value: "",
      rules: [{ required: true, message: "请输入商家名称!" }],
    },
    {
      type: "input",
      label: "商家电话",
      name: "merchantsPhone",
      value: "",
      rules: [{ required: true, message: "请输入商家电话" }],
    },
    {
      type: "input",
      label: "商家实际办公地点",
      name: "address",
      value: "",
      rules: [{ required: true, message: "请输入商家实际办公地点" }],
    },
    {
      type: "inpput",
      label: "运营范围",
      name: "radius",
      value: "",
      rules: [{ required: true, message: "请输入运营范围" }],
    },
    {
      type: "upload",
      label: "营业执照",
      name: "licenseImgList",
      value: [],
      rules: [{ required: true, message: "请上传营业执照" }],
    },
  ];
  const onFinish = (values: any) => {
    let ids = values.licenseImgList.map((item) => {
      return item.id;
    });
    console.log(values);
    values = {
      ...values,
      licenseImgId: ids.join(","),
      desc: productDesc,
    };
    if (!merchantId) {
      merchantStore.add(values);
    } else {
      merchantStore.putItem(merchantId, values);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    merchantStore.getlist(merchantsConfig.LIST);
  }, [merchantStore]);
  const onFinishFailed = () => {};
  return (
    <div style={{ margin: 10 }}>
      <Button
        style={{ marginBottom: 10 }}
        type="default"
        onClick={() => {
          setProjectConfig(defaultConfig);
          setId(null);
          setIsModalOpen(true);
        }}
      >
        添加商户
      </Button>
      <BTable
        columns={columns}
        store={merchantStore}
        dataSource={merchantStore.list}
      />
      <Modal
        title={!merchantId ? "添加商户" : "编辑商户"}
        width={1200}
        open={isModalOpen}
        afterClose={() => formRef.current?.resetFields()}
        onOk={() => formRef.current?.submit()}
        onCancel={() => {
          setId(null);
          setIsModalOpen(false);
        }}
      >
        <SimpleForm
          formRef={formRef}
          createCallback={() => {
            formRef.current?.setFieldsValue(record);
          }}
          formName="card_basic"
          colProps={3}
          subBtnName="提交"
          formDatas={projectConfig}
          onFinish={onFinish}
          initialValues={true}
          onFinishFailed={onFinishFailed}
        />
        <Space align="start">
          <span
            style={{
              width: "130px",
              marginRight: "5px",
              display: "inline-block",
              textAlign: "end",
            }}
          >
            图文介绍:
          </span>
          <EditorComponent
            data={productDesc}
            updateChange={(v) => {
              setProductDesc(v);
            }}
          />
        </Space>
      </Modal>
    </div>
  );
};
export default inject("merchantStore")(observer(Merchant));
