 
import BTable from "@/components/BTable";
import { Button, FormInstance, Modal, Space } from "antd";
import { ColumnsType } from "antd/lib/table";
import { inject, observer } from "mobx-react";
import { Store } from "antd/lib/form/interface";
import { useEffect, useState } from "react";
import merchantsConfig from "@/service/apiConfig/merchants_config";
import SimpleForm from "@/components/form/simple_form";
import React from "react";

const ProductUnit = (props: Store) => {
  const { productUnitStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [merchantId, setId] = useState<Number | null>(null);
  const columns: ColumnsType = [
    { title: "单位名称", dataIndex: "productUnitName" },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: { showTitle: false },
      render: (any, record: any) => (
        <div>
          <Space align="center">
            <Button
              type="dashed"
              size="small"
              onClick={() => {
                edit(record);
              }}
            >
              编辑
            </Button>
            <Button
              type="dashed"
              danger
              size="small"
              onClick={() => {
                productUnitStore.deleteItem(record.id);
              }}
            >
              删除
            </Button>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const defaultConfig = [
    {
      type: "input",
      label: "单位名称",
      name: "productUnitName",
      value: "",
      rules: [{ required: true, message: "请输入单位名称!" }],
    },
    // {
    //   type: "input",
    //   label: "商家电话",
    //   name: "merchantsPhone",
    //   value: "",
    //   rules: [{ required: true, message: "请输入商家电话" }],
    // },
  ];
  const onFinish = (values: any) => {
    values = {
      ...values,
    };
    if (!merchantId) {
      productUnitStore.add(values);
    } else {
      productUnitStore.putItem(merchantId, values);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    productUnitStore.getlist(merchantsConfig.LIST);
  }, [productUnitStore]);
  const onFinishFailed = () => {};
  return (
    <div style={{ margin: 10 }}>
      <Button
        style={{ marginBottom: 10 }}
        type="default"
        onClick={() => {
          setProjectConfig(defaultConfig);
          setId(null);
          setIsModalOpen(true);
        }}
      >
        添加商品类型
      </Button>
      <BTable
        columns={columns}
        store={productUnitStore}
        dataSource={productUnitStore.list}
      />
      <Modal
        title={!merchantId ? "添加商品类型" : "编辑商品类型"}
        width={800}
        open={isModalOpen}
        afterClose={() => formRef.current?.resetFields()}
        onOk={() => formRef.current?.submit()}
        onCancel={() => {
          setId(null);
          setIsModalOpen(false);
        }}
      >
        <SimpleForm
          formRef={formRef}
          createCallback={() => {
            formRef.current?.setFieldsValue(record);
          }}
          formName="card_basic"
          colProps={4}
          subBtnName="提交"
          formDatas={projectConfig}
          onFinish={onFinish}
          initialValues={true}
          onFinishFailed={onFinishFailed}
        />
      </Modal>
    </div>
  );
};
export default inject("productUnitStore")(observer(ProductUnit));
