import BTable from "@/components/BTable";
import { Button, FormInstance, Modal, Space } from "antd";
import { ColumnsType } from "antd/lib/table";
import { inject, observer } from "mobx-react";
import { Store } from "antd/lib/form/interface";
import { useEffect, useState } from "react";
import merchantsConfig from "@/service/apiConfig/merchants_config";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import EditorComponent from "@/components/edittor";
import projectTypeConfig from "@/service/apiConfig/project_type_config";

const Project = (props: Store) => {
  const { projectStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [productDesc, setProductDesc] = useState<any>(null);
  const [merchantId, setId] = useState<Number | null>(null);
  const columns: ColumnsType = [
    { title: "名称", dataIndex: "productName" },
    { title: "简介", dataIndex: "productIntro" },
    { title: "所属类型", dataIndex: "productTypeName" },
    { title: "价格", dataIndex: "productPrice" },
    { title: "库存", dataIndex: "productInventory" },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: { showTitle: false },
      render: (any, record: any) => (
        <div>
          <Space align="center">
            <Button
              type="dashed"
              size="small"
              onClick={() => {
                edit(record);
              }}
            >
              编辑
            </Button>
            <Button
              type="dashed"
              danger
              size="small"
              onClick={() => {
                projectStore.deleteItem(record.id);
              }}
            >
              删除
            </Button>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
    setProductDesc(record.productDesc);
  };
  const defaultConfig = [
    {
      type: "input",
      label: "名称",
      name: "productName",
      value: "",
      rules: [{ required: true, message: "请输入名称!" }],
    },
    {
      type: "input",
      label: "简介",
      name: "productIntro",
      value: "",
      rules: [{ required: true, message: "请输入简介" }],
    },
    {
      type: "input",
      label: "价格",
      name: "productPrice",
      value: "",
      rules: [{ required: true, message: "请输入价格" }],
    },
    {
      type: "select",
      label: "所属类型",
      name: "productTypeId",
      value: "",
      selectUrl: projectTypeConfig.LIST,
      rules: [{ required: true, message: "请选择类型" }],
    },
    {
      type: "inpput",
      label: "库存",
      name: "productInventory",
      value: "",
      rules: [{ required: true, message: "请输入库存" }],
    },
  ];
  const onFinish = (values: any) => {
    // let images = values.imageUrl.map((item) => {
    //   return item.response.data.url;
    // });

    values = {
      ...values,
      headImg: "cascas", //images.join(","),
      productDesc: productDesc,
    };
    if (!merchantId) {
      projectStore.add(values);
    } else {
      projectStore.putItem(merchantId, values);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    projectStore.getlist(merchantsConfig.LIST);
  }, [projectStore]);
  const onFinishFailed = () => {};
  const addAction = () => {
    setProjectConfig(defaultConfig);
    setId(null);
    setIsModalOpen(true);
  };
  return (
    <div style={{ margin: 10 }}>
      <Button style={{ marginBottom: 10 }} type="default" onClick={addAction}>
        添加商品
      </Button>
      <BTable
        columns={columns}
        store={projectStore}
        dataSource={projectStore.list}
      />
      <Modal
        title={!merchantId ? "添加商品" : "编辑商品"}
        width={1200}
        open={isModalOpen}
        afterClose={() => formRef.current?.resetFields()}
        onOk={() => formRef.current?.submit()}
        onCancel={() => {
          setId(null);
          setIsModalOpen(false);
        }}
      >
        <SimpleForm
          formRef={formRef}
          createCallback={() => {
            formRef.current?.setFieldsValue(record);
          }}
          formName="card_basic"
          colProps={3}
          subBtnName="提交"
          formDatas={projectConfig}
          onFinish={onFinish}
          initialValues={true}
          onFinishFailed={onFinishFailed}
        />
        <Space align="start">
          <span
            style={{
              width: "130px",
              display: "inline-block",
              textAlign: "end",
            }}
          >
            图文介绍
          </span>
          <EditorComponent
            data={productDesc}
            updateChange={(v) => {
              setProductDesc(v);
            }}
          />
        </Space>
      </Modal>
    </div>
  );
};
export default inject("projectStore")(observer(Project));
